@@ -688,5 +688,24 @@ mod tests {
         assert_rem("-3", "-2", "-1");
         assert_rem("-3", "-1", "0");
         assert_rem("12.34", "1.233", "0.01");
+        assert_rem("5e42", "0.3", "0.2");
+        assert_rem("-5e42", "0.3", "-0.2");
+        assert_rem("5e42", "-0.3", "0.2");
+        assert_rem("-5e42", "-0.3", "-0.2");
+        assert_rem("5e42", "0.03", "0.02");
+        assert_rem("5e42", "3", "2");
+        assert_rem("5e60", "3", "2");
+        assert_rem("5e60", "300", "200");
+        assert_rem("5e76", "3", "2");
+        assert_rem("5e77", "3", "2e39");
+        assert_rem("5e-42", "3e-84", "2e-84");
+        assert_rem("5e126", "3e-130", "2e88");
+        assert_rem("4e126", "3e-130", "1e88");
+        assert_rem(
+            "99999999999999999999999999999999999999e126",
+            "7e-130",
+            "2e88",
+        );
+        assert_rem("3", "5e42", "3");
     }
 }
