@@ -598,11 +598,11 @@ mod tests {
         assert(U256::from(1_0000_0000_0000_0000u128), 17);
         assert(U256::from(1_0000_0000_0000_0000_0000_0000_0000u128), 29);
         assert(
-            U256::from(1_0_0000_0000_0000_0000_0000_0000_0000_0000_0000u128),
+            U256::from(10_0000_0000_0000_0000_0000_0000_0000_0000_0000u128),
             38,
         );
         assert(
-            U256::from(1_00_0000_0000_0000_0000_0000_0000_0000_0000_0000u128),
+            U256::from(100_0000_0000_0000_0000_0000_0000_0000_0000_0000u128),
             39,
         );
         assert(
